@@ -60,11 +60,11 @@ class ContentExporter(UniqueObject, SimpleItem):
     #   ZMI methods
     #
     security.declareProtected( ManagePortal, 'manage_overview' )
-    manage_overview = PageTemplateFile('www/explainContentMigrator.pt', globals(),
+    manage_overview = PageTemplateFile(os.path.join('www','explainContentMigrator.pt'), globals(),
                                    __name__='manage_overview')
 
     security.declareProtected( ManagePortal, 'manage_export' )
-    manage_export = PageTemplateFile('www/exportContentMigrator.pt', globals(),
+    manage_export = PageTemplateFile(os.path.join('www','exportContentMigrator.pt'), globals(),
                                    __name__='manage_export')
 
 
@@ -179,21 +179,25 @@ class ContentExporter(UniqueObject, SimpleItem):
         info = {'title': 'source_users',
                 'users': user_info,
                }
-        template = PageTemplateFile('xml/zodbusers.xml',
+        template = PageTemplateFile(os.path.join('xml','zodbusers.xml'),
                                     globals()).__of__(portal)
         self.write_file('/acl_users','source_users.xml', template(info=info))
 
-        template = PageTemplateFile('xml/zodbroles.xml',
+        template = PageTemplateFile(os.path.join('xml','zodbroles.xml'),
                                     globals()).__of__(portal)
         info = self._getRoleInfo(portal)
         self.write_file('/acl_users','portal_role_manager.xml',
                                             template(info=info))
-        template = PageTemplateFile('xml/zodbgroups.xml',
+        template = PageTemplateFile(os.path.join('xml','zodbgroups.xml'),
                                     globals()).__of__(portal)
         info = self._getGroupInfo(portal)
         self.write_file('/acl_users','source_groups.xml',
                                      template(info=info))
-        self.write_file(path,'.objects',ostream.getvalue())
+        output = ostream.getvalue()
+        # Windows compatibility fix?
+        if os.path.join('a','b')=='a\b':
+            output = output.replace('\r\r\n','\r\n')
+        self.write_file(path,'.objects',output)
         self.out.append('Exported member data')
 
     def _getRoleInfo(self, portal):
@@ -287,7 +291,11 @@ class ContentExporter(UniqueObject, SimpleItem):
                         self.export_object(id,obj,objtype,path)
                         csv_writer.writerow((id, objtype))
 
-        self.write_file(path,'.objects',ostream.getvalue())
+        output = ostream.getvalue()
+        # Windows compatibility fix?
+        if os.path.join('a','b')=='a\b':
+            output = output.replace('\r\r\n','\r\n')
+        self.write_file(path,'.objects',output)
 
     def export(self, portal, root='/'):
         """ Based on generic setup folder export to structre -
@@ -340,14 +348,20 @@ class ContentExporter(UniqueObject, SimpleItem):
 
         return self.out
 
+
     def export_object(self,id,obj,objtype,path):
         """ export file content to filesystem """
         text = self.properties_marshall(obj)
+        # do required fields
         for prop,data in PROPS['fixed'].items():
+            propname = prop
+            prop = PROPS['boolean'].get(prop, prop)
             if hasattr(obj,prop):
-                if getattr(obj,prop) in (True, False):
-                    data = getattr(obj,prop)
-            text += "%s: %s\n" % (prop,data)
+                if getattr(obj,prop,None):
+                    data = True
+                else:
+                    data = False
+            text += "%s: %s\n" % (propname,data)
         text += self.workflow(obj)
         archetype = self.at_marshall(obj, path)
         text += archetype
